@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: extern_data.cpp 3222 2006-04-28 19:49:53Z mosu $
+   $Id: extern_data.cpp 3540 2007-06-30 09:53:55Z mosu $
 
    Data for ComboBoxes in mmg and other occurences
 
@@ -2132,7 +2132,7 @@ const mime_type_t mime_types[] = {
   {"application/x-troff-man", "man"},
   {"application/x-troff-me", "me"},
   {"application/x-troff-ms", "ms"},
-  {"application/x-truetype-font", "ttf"},
+  {"application/x-truetype-font", "ttf otf"},
   {"application/x-ustar", "ustar"},
   {"application/x-wais-source", "src"},
   {"application/x-wingz", "wz"},
@@ -2653,6 +2653,13 @@ guess_mime_type(string ext,
     int idx = ret.find(';');
     if (-1 != idx)
       ret.erase(idx);
+
+    if (ret == "application/octet-stream")
+      ret = guess_mime_type_by_ext(ext);
+
+    if (ret == "")
+      ret = "application/octet-stream";
+
     return ret;
   }
 #else
