@@ -6,19 +6,27 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: os.cpp 2825 2005-02-27 10:49:27Z mosu $
+   $Id: os.cpp 3946 2008-09-28 21:05:53Z mosu $
 
    OS dependant helper functions
 */
 
-#include "common.h"
-#include "config.h"
 #include "os.h"
 
+#include "common.h"
+#include "config.h"
+#include "mm_io.h"
+
+#include <errno.h>
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/stat.h>
+#include <sys/time.h>
+#include <time.h>
+
+using namespace std;
 
 #if defined(SYS_WINDOWS)
 
@@ -34,7 +42,10 @@
    Additional code by Alexander No <alexander.noe@s2001.tu-chemnitz.de>
 */
 
-#include <windows.h>
+# include <io.h>
+# include <windows.h>
+# include <direct.h>
+# include <sys/timeb.h>
 
 static unsigned
 Utf8ToUtf16(const char *utf8,
@@ -117,6 +128,35 @@ Utf8ToUtf16(const char *utf8,
   return (unsigned)(d - utf16);
 }
 
+static bool
+win32_is_unicode_possible() {
+  OSVERSIONINFOEX ovi;
+
+  ovi.dwOSVersionInfoSize = sizeof(ovi);
+  GetVersionEx((OSVERSIONINFO *)&ovi);
+  return ovi.dwPlatformId == VER_PLATFORM_WIN32_NT;
+}
+
+static char *
+win32_wide_to_multi(const wchar_t *wbuffer) {
+  int reqbuf = WideCharToMultiByte(CP_ACP, 0, wbuffer, -1, NULL, 0, NULL,
+                                   NULL);
+  char *buffer = new char[reqbuf];
+  WideCharToMultiByte(CP_ACP, 0, wbuffer, -1, buffer, reqbuf, NULL, NULL);
+
+  return buffer;
+}
+
+static wchar_t *
+win32_utf8_to_utf16(const char *s) {
+  int wreqbuf = Utf8ToUtf16(s, -1, NULL, 0);
+  wchar_t *wbuffer = new wchar_t[wreqbuf];
+
+  Utf8ToUtf16(s, -1, wbuffer, wreqbuf);
+
+  return wbuffer;
+}
+
 HANDLE
 CreateFileUtf8(LPCSTR lpFileName,
                DWORD dwDesiredAccess,
@@ -125,27 +165,16 @@ CreateFileUtf8(LPCSTR lpFileName,
                DWORD dwCreationDisposition,
                DWORD dwFlagsAndAttributes,
                HANDLE hTemplateFile) {
-  OSVERSIONINFOEX ovi;
-  bool unicode_possible;
   HANDLE ret;
   // convert the name to wide chars
-  int wreqbuf = Utf8ToUtf16(lpFileName, -1, NULL, 0);
-  wchar_t *wbuffer = new wchar_t[wreqbuf];
-  Utf8ToUtf16(lpFileName, -1, wbuffer, wreqbuf);
+  wchar_t *wbuffer = win32_utf8_to_utf16(lpFileName);
 
-  ovi.dwOSVersionInfoSize = sizeof(ovi);
-  GetVersionEx((OSVERSIONINFO *)&ovi);
-  unicode_possible = ovi.dwPlatformId == VER_PLATFORM_WIN32_NT;
-
-  if (unicode_possible)
+  if (win32_is_unicode_possible())
     ret = CreateFileW(wbuffer, dwDesiredAccess, dwShareMode,
                       lpSecurityAttributes, dwCreationDisposition,
                       dwFlagsAndAttributes, hTemplateFile);
   else {
-    int reqbuf = WideCharToMultiByte(CP_ACP, 0, wbuffer, -1, NULL, 0, NULL,
-                                     NULL);
-    char *buffer = new char[reqbuf];
-    WideCharToMultiByte(CP_ACP, 0, wbuffer, -1, buffer, reqbuf, NULL, NULL);
+    char *buffer = win32_wide_to_multi(wbuffer);
     ret = CreateFileA(buffer, dwDesiredAccess, dwShareMode,
                       lpSecurityAttributes, dwCreationDisposition,
                       dwFlagsAndAttributes, hTemplateFile);
@@ -157,6 +186,85 @@ CreateFileUtf8(LPCSTR lpFileName,
 
   return ret;
 }
+
+void
+create_directory(const char *path) {
+  wchar_t *wbuffer = win32_utf8_to_utf16(path);
+  int result;
+
+  if (win32_is_unicode_possible())
+    result = _wmkdir(wbuffer);
+
+  else {
+    char *buffer = win32_wide_to_multi(wbuffer);
+    result = _mkdir(buffer);
+
+    delete []buffer;
+  }
+
+  delete []wbuffer;
+
+  if (0 != result)
+    throw error_c(boost::format(Y("mkdir(%1%) failed; errno = %2% (%3%)")) % path % errno % strerror(errno));
+}
+
+int
+fs_entry_exists(const char *path) {
+  wchar_t *wbuffer = win32_utf8_to_utf16(path);
+  struct _stat s;
+  int result;
+
+  if (win32_is_unicode_possible())
+    result = _wstat(wbuffer, &s);
+
+  else {
+    char *buffer = win32_wide_to_multi(wbuffer);
+
+    result = _stat(buffer, &s);
+    delete []buffer;
+  }
+
+  delete []wbuffer;
+
+  return 0 == result;
+}
+
+int64_t
+get_current_time_millis() {
+  struct _timeb tb;
+  _ftime(&tb);
+
+  return (int64_t)tb.time * 1000 + tb.millitm;
+}
+
+#else // SYS_WINDOWS
+
+# include <sys/types.h>
+# include <unistd.h>
+
+void
+create_directory(const char *path) {
+  string local_path = from_utf8(cc_local_utf8, path);
+  if (0 != mkdir(local_path.c_str(), 0777))
+    throw error_c(boost::format(Y("mkdir(%1%) failed; errno = %2% (%3%)")) % path % errno % strerror(errno));
+}
+
+int
+fs_entry_exists(const char *path) {
+  string local_path = from_utf8(cc_local_utf8, path);
+  struct stat s;
+  return 0 == stat(local_path.c_str(), &s);
+}
+
+int64_t
+get_current_time_millis() {
+  struct timeval tv;
+  if (0 != gettimeofday(&tv, NULL))
+    return -1;
+
+  return (int64_t)tv.tv_sec * 1000 + (int64_t)tv.tv_usec / 1000;
+}
+
 #endif // SYS_WINDOWS
 
 // -----------------------------------------------------------------
