@@ -5,7 +5,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: tracks.cpp 3461 2007-01-12 14:44:59Z mosu $
+   $Id: tracks.cpp 3986 2008-10-11 16:46:03Z mosu $
 
    extracts tracks from Matroska files into other files
 
@@ -14,20 +14,7 @@
 
 #include "os.h"
 
-#include <errno.h>
-#include <ctype.h>
-#include <stdarg.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <time.h>
-
-#if defined(COMP_MSC)
 #include <cassert>
-#else
-#include <unistd.h>
-#endif
-
 #include <string>
 #include <vector>
 
@@ -49,7 +36,6 @@
 #include <matroska/KaxTrackAudio.h>
 #include <matroska/KaxTrackVideo.h>
 
-#include "chapters.h"
 #include "common.h"
 #include "commonebml.h"
 #include "matroska.h"
@@ -71,29 +57,22 @@ create_extractors(KaxTracks &kax_tracks,
   int i;
 
   for (i = 0; i < kax_tracks.ListSize(); i++) {
-    int k;
-    int64_t tnum;
-    string codec_id;
-    xtr_base_c *extractor, *master;
-    track_spec_t *tspec;
-
     if (!is_id(kax_tracks[i], KaxTrackEntry))
       continue;
 
     KaxTrackEntry &track = *static_cast<KaxTrackEntry *>(kax_tracks[i]);
-
-    tnum = kt_get_number(track);
+    int64_t tnum         = kt_get_number(track);
 
     // Is the track number present and valid?
     if (0 == tnum)
       continue;
 
     // Is there more than one track with the same track number?
-    extractor = NULL;
+    xtr_base_c *extractor = NULL;
+    int k;
     for (k = 0; k < extractors.size(); k++)
-      if (extractors[k]->tid == tnum) {
-        mxwarn("More than one track with the track number " LLD " found.\n",
-               tnum);
+      if (extractors[k]->m_tid == tnum) {
+        mxwarn(boost::format(Y("More than one track with the track number %1% found.\n")) % tnum);
         extractor = extractors[k];
         break;
       }
@@ -101,7 +80,7 @@ create_extractors(KaxTracks &kax_tracks,
       continue;
 
     // Does the user want this track to be extracted?
-    tspec = NULL;
+    track_spec_t *tspec = NULL;
     for (k = 0; k < tracks.size(); k++)
       if (tracks[k].tid == tnum) {
         tspec = &tracks[k];
@@ -111,20 +90,18 @@ create_extractors(KaxTracks &kax_tracks,
       continue;
 
     // Let's find the codec ID and create an extractor for it.
-    codec_id = kt_get_codec_id(track);
+    string codec_id = kt_get_codec_id(track);
     if (codec_id.empty())
-      mxerror("The track number " LLD " does not have a valid CodecID.\n",
-              tnum);
+      mxerror(boost::format(Y("The track number %1% does not have a valid CodecID.\n")) % tnum);
 
     extractor = xtr_base_c::create_extractor(codec_id, tnum, *tspec);
     if (NULL == extractor)
-      mxerror("Extraction of track number " LLD " with the CodecID '%s' is "
-              "not supported.\n", tnum, codec_id.c_str());
+      mxerror(boost::format(Y("Extraction of track number %1% with the CodecID '%2%' is not supported.\n")) % tnum % codec_id);
 
     // Has there another file been requested with the same name?
-    master = NULL;
+    xtr_base_c *master = NULL;
     for (k = 0; k < extractors.size(); k++)
-      if (extractors[k]->file_name == tspec->out_name) {
+      if (extractors[k]->m_file_name == tspec->out_name) {
         master = extractors[k];
         break;
       }
@@ -135,9 +112,8 @@ create_extractors(KaxTracks &kax_tracks,
     // We're done.
     extractors.push_back(extractor);
 
-    mxinfo("Extracting track " LLD " with the CodecID '%s' to the file '%s'. "
-           "Container format: %s\n", tnum, codec_id.c_str(), tspec->out_name,
-           extractor->get_container_name());
+    mxinfo(boost::format(Y("Extracting track %1% with the CodecID '%2%' to the file '%3%'. Container format: %4%\n"))
+           % tnum % codec_id % tspec->out_name % extractor->get_container_name());
   }
 
   // Signal that all headers have been taken care of.
@@ -149,25 +125,18 @@ static void
 handle_blockgroup(KaxBlockGroup &blockgroup,
                   KaxCluster &cluster,
                   int64_t tc_scale) {
-  KaxBlock *block;
-  KaxBlockDuration *kduration;
-  KaxReferenceBlock *kreference;
-  KaxBlockAdditions *kadditions;
-  xtr_base_c *extractor;
-  int64_t duration, fref, bref;
-  int i;
-
   // Only continue if this block group actually contains a block.
-  block = FINDFIRST(&blockgroup, KaxBlock);
+  KaxBlock *block = FINDFIRST(&blockgroup, KaxBlock);
   if ((NULL == block) || (0 == block->NumberFrames()))
     return;
 
   block->SetParent(cluster);
 
   // Do we need this block group?
-  extractor = NULL;
+  xtr_base_c *extractor = NULL;
+  int i;
   for (i = 0; i < extractors.size(); i++)
-    if (block->TrackNum() == extractors[i]->tid) {
+    if (block->TrackNum() == extractors[i]->m_tid) {
       extractor = extractors[i];
       break;
     }
@@ -175,18 +144,15 @@ handle_blockgroup(KaxBlockGroup &blockgroup,
     return;
 
   // Next find the block duration if there is one.
-  kduration = FINDFIRST(&blockgroup, KaxBlockDuration);
-  if (NULL == kduration)
-    duration = -1;
-  else
-    duration = uint64(*kduration) * tc_scale;
+  KaxBlockDuration *kduration   = FINDFIRST(&blockgroup, KaxBlockDuration);
+  int64_t duration              = NULL == kduration ? -1 : (int64_t)uint64(*kduration) * tc_scale;
 
   // Now find backward and forward references.
-  bref = 0;
-  fref = 0;
-  kreference = FINDFIRST(&blockgroup, KaxReferenceBlock);
+  int64_t bref                  = 0;
+  int64_t fref                  = 0;
+  KaxReferenceBlock *kreference = FINDFIRST(&blockgroup, KaxReferenceBlock);
   for (i = 0; (2 > i) && (NULL != kreference); i++) {
-    if (int64(*kreference) < 0)
+    if (0 > int64(*kreference))
       bref = int64(*kreference);
     else
       fref = int64(*kreference);
@@ -194,10 +160,16 @@ handle_blockgroup(KaxBlockGroup &blockgroup,
   }
 
   // Any block additions present?
-  kadditions = FINDFIRST(&blockgroup, KaxBlockAdditions);
+  KaxBlockAdditions *kadditions = FINDFIRST(&blockgroup, KaxBlockAdditions);
 
   if (0 > duration)
-    duration = extractor->default_duration * block->NumberFrames();
+    duration = extractor->m_default_duration * block->NumberFrames();
+
+  KaxCodecState *kcstate = FINDFIRST(&blockgroup, KaxCodecState);
+  if (NULL != kcstate) {
+    memory_cptr codec_state(new memory_c(kcstate->GetBuffer(), kcstate->GetSize(), false));
+    extractor->handle_codec_state(codec_state);
+  }
 
   for (i = 0; i < block->NumberFrames(); i++) {
     int64_t this_timecode, this_duration;
@@ -213,27 +185,23 @@ handle_blockgroup(KaxBlockGroup &blockgroup,
 
     DataBuffer &data = block->GetBuffer(i);
     memory_cptr frame(new memory_c(data.Buffer(), data.Size(), false));
-    extractor->handle_frame(frame, kadditions, this_timecode, this_duration,
-                            bref, fref, false, false, true);
+    extractor->handle_frame(frame, kadditions, this_timecode, this_duration, bref, fref, false, false, true);
   }
 }
 
 static void
 handle_simpleblock(KaxSimpleBlock &simpleblock,
                    KaxCluster &cluster) {
-  xtr_base_c *extractor;
-  int64_t duration;
-  size_t i;
-
   if (0 == simpleblock.NumberFrames())
     return;
 
   simpleblock.SetParent(cluster);
 
   // Do we need this block group?
-  extractor = NULL;
+  xtr_base_c *extractor = NULL;
+  size_t i;
   for (i = 0; i < extractors.size(); i++)
-    if (simpleblock.TrackNum() == extractors[i]->tid) {
+    if (simpleblock.TrackNum() == extractors[i]->m_tid) {
       extractor = extractors[i];
       break;
     }
@@ -241,7 +209,7 @@ handle_simpleblock(KaxSimpleBlock &simpleblock,
   if (NULL == extractor)
     return;
 
-  duration = extractor->default_duration * simpleblock.NumberFrames();
+  int64_t duration = extractor->m_default_duration * simpleblock.NumberFrames();
 
   for (i = 0; i < simpleblock.NumberFrames(); i++) {
     int64_t this_timecode, this_duration;
@@ -250,16 +218,13 @@ handle_simpleblock(KaxSimpleBlock &simpleblock,
       this_timecode = simpleblock.GlobalTimecode();
       this_duration = duration;
     } else {
-      this_timecode = simpleblock.GlobalTimecode() + i * duration /
-        simpleblock.NumberFrames();
+      this_timecode = simpleblock.GlobalTimecode() + i * duration / simpleblock.NumberFrames();
       this_duration = duration / simpleblock.NumberFrames();
     }
 
     DataBuffer &data = simpleblock.GetBuffer(i);
     memory_cptr frame(new memory_c(data.Buffer(), data.Size(), false));
-    extractor->handle_frame(frame, NULL, this_timecode, this_duration,
-                            -1, -1, simpleblock.IsKeyframe(),
-                            simpleblock.IsDiscardable(), false);
+    extractor->handle_frame(frame, NULL, this_timecode, this_duration, -1, -1, simpleblock.IsKeyframe(), simpleblock.IsDiscardable(), false);
   }
 }
 
@@ -269,14 +234,17 @@ close_extractors() {
 
   for (i = 0; i < extractors.size(); i++)
     extractors[i]->finish_track();
+
   for (i = 0; i < extractors.size(); i++)
-    if (NULL != extractors[i]->master)
+    if (NULL != extractors[i]->m_master)
       extractors[i]->finish_file();
+
   for (i = 0; i < extractors.size(); i++) {
-    if (NULL == extractors[i]->master)
+    if (NULL == extractors[i]->m_master)
       extractors[i]->finish_file();
     delete extractors[i];
   }
+
   extractors.clear();
 }
 
@@ -285,39 +253,35 @@ write_all_cuesheets(KaxChapters &chapters,
                     KaxTags &tags,
                     vector<track_spec_t> &tspecs) {
   int i;
-  mm_io_c *out;
-
-  out = NULL;
+  mm_io_c *out = NULL;
 
   for (i = 0; i < tspecs.size(); i++) {
     if (tspecs[i].extract_cuesheet) {
-      string file_name, cue_file_name;
-      int pos, pos2, pos3;
+      string file_name = tspecs[i].out_name;
+      int pos          = file_name.rfind('/');
+      int pos2         = file_name.rfind('\\');
 
-      file_name = tspecs[i].out_name;
-      pos = file_name.rfind('/');
-      pos2 = file_name.rfind('\\');
       if (pos2 > pos)
         pos = pos2;
       if (pos >= 0)
         file_name.erase(0, pos2);
 
-      cue_file_name = (string)tspecs[i].out_name;
-      pos = cue_file_name.rfind('.');
-      pos2 = cue_file_name.rfind('/');
-      pos3 = cue_file_name.rfind('\\');
-      if ((pos >= 0) && (pos > pos2) && (pos > pos3))
+      string cue_file_name = (string)tspecs[i].out_name;
+      pos                  = cue_file_name.rfind('.');
+      pos2                 = cue_file_name.rfind('/');
+      int pos3             = cue_file_name.rfind('\\');
+
+      if ((0 <= pos) && (pos > pos2) && (pos > pos3))
         cue_file_name.erase(pos);
       cue_file_name += ".cue";
 
       try {
         out = new mm_file_io_c(cue_file_name.c_str(), MODE_CREATE);
       } catch(...) {
-        mxerror(_("The file '%s' could not be opened for writing (%s).\n"),
-                cue_file_name.c_str(), strerror(errno));
+        mxerror(boost::format(Y("The file '%1%' could not be opened for writing (%2%).\n")) % cue_file_name % strerror(errno));
       }
-      mxinfo(_("The CUE sheet for track " LLD " will be written to '%s'.\n"),
-             tspecs[i].tid, cue_file_name.c_str());
+
+      mxinfo(boost::format(Y("The CUE sheet for track %1% will be written to '%2%'.\n")) % tspecs[i].tid % cue_file_name);
       write_cuesheet(file_name.c_str(), chapters, tags, tspecs[i].tuid, *out);
       delete out;
     }
@@ -330,17 +294,14 @@ find_track_uids(KaxTracks &tracks,
   int t;
 
   for (t = 0; t < tracks.ListSize(); t++) {
-    KaxTrackEntry *track_entry;
-    int64_t track_number;
-    int s;
-
-    track_entry = dynamic_cast<KaxTrackEntry *>(tracks[t]);
+    KaxTrackEntry *track_entry = dynamic_cast<KaxTrackEntry *>(tracks[t]);
     if (NULL == track_entry)
       continue;
 
-    track_number = kt_get_number(*track_entry);
+    int64_t track_number = kt_get_number(*track_entry);
 
-    for (s = 0; s < tspecs.size(); s++)
+    int s;
+    for (s = 0; tspecs.size() > s; ++s)
       if (tspecs[s].tid == track_number) {
         tspecs[s].tuid = kt_get_uid(*track_entry);
         break;
@@ -351,37 +312,24 @@ find_track_uids(KaxTracks &tracks,
 bool
 extract_tracks(const char *file_name,
                vector<track_spec_t> &tspecs) {
-  int upper_lvl_el;
-  // Elements for different levels
-  EbmlElement *l0 = NULL, *l1 = NULL, *l2 = NULL, *l3 = NULL;
-  EbmlStream *es;
-  KaxCluster *cluster;
-  uint64_t cluster_tc, tc_scale = TIMECODE_SCALE, file_size;
-  bool tracks_found;
-  mm_io_c *in;
-  KaxChapters all_chapters;
-  KaxTags all_tags;
-
   // open input file
+  mm_io_c *in;
   try {
     in = new mm_file_io_c(file_name);
   } catch (...) {
-    show_error(_("The file '%s' could not be opened for reading (%s).\n"),
-               file_name, strerror(errno));
+    show_error(boost::format(Y("The file '%1%' could not be opened for reading (%2%).\n")) % file_name % strerror(errno));
     return false;
   }
 
-  in->setFilePointer(0, seek_end);
-  file_size = in->getFilePointer();
-  in->setFilePointer(0, seek_beginning);
+  int64_t file_size = in->get_size();
 
   try {
-    es = new EbmlStream(*in);
+    EbmlStream *es = new EbmlStream(*in);
 
     // Find the EbmlHead element. Must be the first one.
-    l0 = es->FindNextID(EbmlHead::ClassInfos, 0xFFFFFFFFL);
-    if (l0 == NULL) {
-      show_error(_("Error: No EBML head found."));
+    EbmlElement *l0 = es->FindNextID(EbmlHead::ClassInfos, 0xFFFFFFFFL);
+    if (NULL == l0) {
+      show_error(Y("Error: No EBML head found."));
       delete es;
 
       return false;
@@ -394,12 +342,14 @@ extract_tracks(const char *file_name,
     while (1) {
       // Next element must be a segment
       l0 = es->FindNextID(KaxSegment::ClassInfos, 0xFFFFFFFFFFFFFFFFLL);
-      if (l0 == NULL) {
-        show_error(_("No segment/level 0 element found."));
+
+      if (NULL == l0) {
+        show_error(Y("No segment/level 0 element found."));
         return false;
       }
+
       if (EbmlId(*l0) == KaxSegment::ClassInfos.GlobalId) {
-        show_element(l0, 0, _("Segment"));
+        show_element(l0, 0, Y("Segment"));
         break;
       }
 
@@ -407,27 +357,35 @@ extract_tracks(const char *file_name,
       delete l0;
     }
 
-    tracks_found = false;
-
-    upper_lvl_el = 0;
+    bool tracks_found = false;
+    int upper_lvl_el  = 0;
     // We've got our segment, so let's find the tracks
-    l1 = es->FindNextElement(l0->Generic().Context, upper_lvl_el, 0xFFFFFFFFL,
-                             true, 1);
-    while ((l1 != NULL) && (upper_lvl_el <= 0)) {
+    EbmlElement *l1     = es->FindNextElement(l0->Generic().Context, upper_lvl_el, 0xFFFFFFFFFFFFFFFFLL, true, 1);
+    EbmlElement *l2     = NULL;
+    EbmlElement *l3     = NULL;
+
+    uint64_t tc_scale   = TIMECODE_SCALE;
+    uint64_t cluster_tc = 0;
+
+    KaxCluster *cluster = NULL;
+    KaxChapters all_chapters;
+    KaxTags all_tags;
+
+    while ((NULL != l1) && (0 >= upper_lvl_el)) {
       if (EbmlId(*l1) == KaxInfo::ClassInfos.GlobalId) {
         // General info about this Matroska file
-        show_element(l1, 1, _("Segment information"));
+        show_element(l1, 1, Y("Segment information"));
 
         upper_lvl_el = 0;
-        l2 = es->FindNextElement(l1->Generic().Context, upper_lvl_el,
-                                 0xFFFFFFFFL, true, 1);
-        while ((l2 != NULL) && (upper_lvl_el <= 0)) {
+        l2           = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true, 1);
+
+        while ((NULL != l2) && (0 >= upper_lvl_el)) {
 
           if (EbmlId(*l2) == KaxTimecodeScale::ClassInfos.GlobalId) {
             KaxTimecodeScale &ktc_scale = *static_cast<KaxTimecodeScale *>(l2);
             ktc_scale.ReadData(es->I_O());
             tc_scale = uint64(ktc_scale);
-            show_element(l2, 2, _("Timecode scale: " LLU), tc_scale);
+            show_element(l2, 2, boost::format(Y("Timecode scale: %1%")) % tc_scale);
           } else
             l2->SkipData(*es, l2->Generic().Context);
 
@@ -436,26 +394,23 @@ extract_tracks(const char *file_name,
             break;
           }
 
-          if (upper_lvl_el < 0) {
+          if (0 > upper_lvl_el) {
             upper_lvl_el++;
-            if (upper_lvl_el < 0)
+            if (0 > upper_lvl_el)
               break;
 
           }
 
           l2->SkipData(*es, l2->Generic().Context);
           delete l2;
-          l2 = es->FindNextElement(l1->Generic().Context, upper_lvl_el,
-                                   0xFFFFFFFFL, true);
-
+          l2 = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
         }
 
-      } else if ((EbmlId(*l1) == KaxTracks::ClassInfos.GlobalId) &&
-                 !tracks_found) {
+      } else if ((EbmlId(*l1) == KaxTracks::ClassInfos.GlobalId) && !tracks_found) {
 
         // Yep, we've found our KaxTracks element. Now find all tracks
         // contained in this segment.
-        show_element(l1, 1, _("Segment tracks"));
+        show_element(l1, 1, Y("Segment tracks"));
 
         tracks_found = true;
         l1->Read(*es, KaxTracks::ClassInfos.Context, upper_lvl_el, l2, true);
@@ -463,39 +418,33 @@ extract_tracks(const char *file_name,
         create_extractors(*dynamic_cast<KaxTracks *>(l1), tspecs);
 
       } else if (EbmlId(*l1) == KaxCluster::ClassInfos.GlobalId) {
-        show_element(l1, 1, _("Cluster"));
+        show_element(l1, 1, Y("Cluster"));
         cluster = (KaxCluster *)l1;
 
-        if (verbose == 0)
-          mxinfo("%s: %d%%\r", _("progress"),
-                 (int)(in->getFilePointer() * 100 / file_size));
+        if (0 == verbose)
+          mxinfo(boost::format(Y("Progress: %1%%%\r")) % (int)(in->getFilePointer() * 100 / file_size));
 
         upper_lvl_el = 0;
-        l2 = es->FindNextElement(l1->Generic().Context, upper_lvl_el,
-                                 0xFFFFFFFFL, true, 1);
-        while ((l2 != NULL) && (upper_lvl_el <= 0)) {
+        l2           = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true, 1);
+        while ((NULL != l2) && (0 >= upper_lvl_el)) {
 
           if (EbmlId(*l2) == KaxClusterTimecode::ClassInfos.GlobalId) {
             KaxClusterTimecode &ctc = *static_cast<KaxClusterTimecode *>(l2);
             ctc.ReadData(es->I_O());
             cluster_tc = uint64(ctc);
-            show_element(l2, 2, _("Cluster timecode: %.3fs"),
-                         (float)cluster_tc * (float)tc_scale / 1000000000.0);
+            show_element(l2, 2, boost::format(Y("Cluster timecode: %|1$.3f|s")) % ((float)cluster_tc * (float)tc_scale / 1000000000.0));
             cluster->InitTimecode(cluster_tc, tc_scale);
 
           } else if (EbmlId(*l2) == KaxBlockGroup::ClassInfos.GlobalId) {
-            show_element(l2, 2, _("Block group"));
+            show_element(l2, 2, Y("Block group"));
 
-            l2->Read(*es, KaxBlockGroup::ClassInfos.Context, upper_lvl_el, l3,
-                     true);
-            handle_blockgroup(*static_cast<KaxBlockGroup *>(l2), *cluster,
-                              tc_scale);
+            l2->Read(*es, KaxBlockGroup::ClassInfos.Context, upper_lvl_el, l3, true);
+            handle_blockgroup(*static_cast<KaxBlockGroup *>(l2), *cluster, tc_scale);
 
           } else if (EbmlId(*l2) == KaxSimpleBlock::ClassInfos.GlobalId) {
-            show_element(l2, 2, _("SimpleBlock"));
+            show_element(l2, 2, Y("SimpleBlock"));
 
-            l2->Read(*es, KaxSimpleBlock::ClassInfos.Context, upper_lvl_el, l3,
-                     true);
+            l2->Read(*es, KaxSimpleBlock::ClassInfos.Context, upper_lvl_el, l3, true);
             handle_simpleblock(*static_cast<KaxSimpleBlock *>(l2), *cluster);
 
           } else
@@ -506,36 +455,33 @@ extract_tracks(const char *file_name,
             break;
           }
 
-          if (upper_lvl_el > 0) {
+          if (0 < upper_lvl_el) {
             upper_lvl_el--;
-            if (upper_lvl_el > 0)
+            if (0 < upper_lvl_el)
               break;
             delete l2;
             l2 = l3;
             continue;
 
-          } else if (upper_lvl_el < 0) {
+          } else if (0 > upper_lvl_el) {
             upper_lvl_el++;
-            if (upper_lvl_el < 0)
+            if (0 > upper_lvl_el)
               break;
 
           }
 
           l2->SkipData(*es, l2->Generic().Context);
           delete l2;
-          l2 = es->FindNextElement(l1->Generic().Context, upper_lvl_el,
-                                   0xFFFFFFFFL, true);
+          l2 = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
 
         } // while (l2 != NULL)
 
       } else if (EbmlId(*l1) == KaxChapters::ClassInfos.GlobalId) {
         KaxChapters &chapters = *static_cast<KaxChapters *>(l1);
-        chapters.Read(*es, KaxChapters::ClassInfos.Context, upper_lvl_el, l2,
-                      true);
+        chapters.Read(*es, KaxChapters::ClassInfos.Context, upper_lvl_el, l2, true);
         while (chapters.ListSize() > 0) {
           if (EbmlId(*chapters[0]) == KaxEditionEntry::ClassInfos.GlobalId) {
-            KaxEditionEntry &entry =
-              *static_cast<KaxEditionEntry *>(chapters[0]);
+            KaxEditionEntry &entry = *static_cast<KaxEditionEntry *>(chapters[0]);
             while (entry.ListSize() > 0) {
               if (EbmlId(*entry[0]) == KaxChapterAtom::ClassInfos.GlobalId)
                 all_chapters.PushElement(*entry[0]);
@@ -562,25 +508,24 @@ extract_tracks(const char *file_name,
         break;
       }
 
-      if (upper_lvl_el > 0) {
+      if (0 < upper_lvl_el) {
         upper_lvl_el--;
-        if (upper_lvl_el > 0)
+        if (0 < upper_lvl_el)
           break;
         delete l1;
         l1 = l2;
         continue;
 
-      } else if (upper_lvl_el < 0) {
+      } else if (0 > upper_lvl_el) {
         upper_lvl_el++;
-        if (upper_lvl_el < 0)
+        if (0 > upper_lvl_el)
           break;
 
       }
 
       l1->SkipData(*es, l1->Generic().Context);
       delete l1;
-      l1 = es->FindNextElement(l0->Generic().Context, upper_lvl_el,
-                               0xFFFFFFFFL, true);
+      l1 = es->FindNextElement(l0->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
 
     } // while (l1 != NULL)
 
@@ -597,7 +542,7 @@ extract_tracks(const char *file_name,
 
     return true;
   } catch (...) {
-    show_error("Caught exception");
+    show_error(Y("Caught exception"));
     delete in;
 
     return false;
