@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_wav.cpp 3867 2008-08-28 10:04:21Z mosu $
+   $Id: r_wav.cpp 3985 2008-10-11 16:00:12Z mosu $
 
    WAV reader module
 
@@ -17,6 +17,8 @@
 
 #include "os.h"
 
+#include <algorithm>
+
 #if defined(COMP_CYGWIN)
 #include <sys/unistd.h>         // Needed for swab()
 #elif __GNUC__ == 2
@@ -210,7 +212,7 @@ wav_ac3acm_demuxer_c::probe(mm_io_cptr &io) {
   if (-1 == pos)
     return false;
 
-  find_ac3_header(m_buf[m_cur_buf]->get() + pos, len - pos, &m_ac3header);
+  find_ac3_header(m_buf[m_cur_buf]->get() + pos, len - pos, &m_ac3header, true);
 
   return true;
 }
@@ -227,9 +229,9 @@ wav_ac3acm_demuxer_c::decode_buffer(int len) {
 
 generic_packetizer_c *
 wav_ac3acm_demuxer_c::create_packetizer() {
-  m_ptzr = new ac3_packetizer_c(m_reader, m_ac3header.sample_rate, m_ac3header.channels, m_ac3header.bsid, m_reader->ti);
+  m_ptzr = new ac3_packetizer_c(m_reader, m_reader->ti, m_ac3header.sample_rate, m_ac3header.channels, m_ac3header.bsid);
 
-  mxinfo(FMT_TID "Using the AC3 output module.\n", m_reader->ti.fname.c_str(), (int64_t)0);
+  mxinfo_tid(m_reader->ti.fname, 0, Y("Using the AC3 output module.\n"));
 
   return m_ptzr;
 }
@@ -287,7 +289,7 @@ wav_ac3wav_demuxer_c::decode_buffer(int len) {
   if ((payload_len + 8) > len)
     return -1;
 
-  int pos = find_ac3_header(&base[8], payload_len, &m_ac3header);
+  int pos = find_ac3_header(&base[8], payload_len, &m_ac3header, true);
 
   return 0 == pos ? payload_len : -1;
 }
@@ -327,7 +329,7 @@ wav_dts_demuxer_c::probe(mm_io_cptr &io) {
   if (detect_dts(m_buf[m_cur_buf]->get(), len, m_pack_14_16, m_swap_bytes)) {
     len = decode_buffer(len);
     if (find_dts_header(m_buf[m_cur_buf]->get(), len, &m_dtsheader) >= 0) {
-      mxverb(3, "DTSinWAV: 14->16 %d swap %d\n", m_pack_14_16, m_swap_bytes);
+      mxverb(3, boost::format(Y("DTSinWAV: 14->16 %1% swap %2%\n")) % m_pack_14_16 % m_swap_bytes);
       return true;
     }
   }
@@ -353,12 +355,12 @@ wav_dts_demuxer_c::decode_buffer(int len) {
 
 generic_packetizer_c *
 wav_dts_demuxer_c::create_packetizer() {
-  m_ptzr = new dts_packetizer_c(m_reader, m_dtsheader, m_reader->ti);
+  m_ptzr = new dts_packetizer_c(m_reader, m_reader->ti, m_dtsheader);
 
   // .wav with DTS are always filled up with other stuff to match the bitrate.
-  ((dts_packetizer_c *)m_ptzr)->skipping_is_normal = true;
+  ((dts_packetizer_c *)m_ptzr)->set_skipping_is_normal(true);
 
-  mxinfo(FMT_TID "Using the DTS output module.\n", m_reader->ti.fname.c_str(), (int64_t)0);
+  mxinfo_tid(m_reader->ti.fname, 0, Y("Using the DTS output module.\n"));
 
   if (1 < verbose)
     print_dts_header(&m_dtsheader);
@@ -393,13 +395,13 @@ wav_pcm_demuxer_c::~wav_pcm_demuxer_c() {
 
 generic_packetizer_c *
 wav_pcm_demuxer_c::create_packetizer() {
-  m_ptzr = new pcm_packetizer_c(m_reader,
+  m_ptzr = new pcm_packetizer_c(m_reader, m_reader->ti,
                                 get_uint32_le(&m_wheader->common.dwSamplesPerSec),
                                 get_uint16_le(&m_wheader->common.wChannels),
                                 get_uint16_le(&m_wheader->common.wBitsPerSample),
-                                m_reader->ti, false, ieee_float);
+                                false, ieee_float);
 
-  mxinfo(FMT_TID "Using the PCM output module.\n", m_reader->ti.fname.c_str(), (int64_t)0);
+  mxinfo_tid(m_reader->ti.fname, 0, Y("Using the PCM output module.\n"));
 
   return m_ptzr;
 }
@@ -453,11 +455,11 @@ wav_reader_c::wav_reader_c(track_info_c &ti_)
     size = m_io->getFilePointer();
     m_io->setFilePointer(0, seek_beginning);
   } catch (...) {
-    throw error_c("wav_reader: Could not open the source file.");
+    throw error_c(Y("wav_reader: Could not open the source file."));
   }
 
   if (!wav_reader_c::probe_file(m_io.get(), size))
-    throw error_c("wav_reader: Source is not a valid WAVE file.");
+    throw error_c(Y("wav_reader: Source is not a valid WAVE file."));
 
   parse_file();
   create_demuxer();
@@ -471,21 +473,21 @@ wav_reader_c::parse_file() {
   int chunk_idx;
 
   if (m_io->read(&m_wheader.riff, sizeof(m_wheader.riff)) != sizeof(m_wheader.riff))
-    throw error_c("wav_reader: could not read WAVE header.");
+    throw error_c(Y("wav_reader: could not read WAVE header."));
 
   scan_chunks();
 
   if ((chunk_idx = find_chunk("fmt ")) == -1)
-    throw error_c("wav_reader: No format chunk found.");
+    throw error_c(Y("wav_reader: No format chunk found."));
 
   m_io->setFilePointer(m_chunks[chunk_idx].pos, seek_beginning);
 
   if ((m_io->read(&m_wheader.format, sizeof(m_wheader.format)) != sizeof(m_wheader.format)) ||
       (m_io->read(&m_wheader.common, sizeof(m_wheader.common)) != sizeof(m_wheader.common)))
-    throw error_c("wav_reader: The format chunk could not be read.");
+    throw error_c(Y("wav_reader: The format chunk could not be read."));
 
   if ((m_cur_data_chunk_idx = find_chunk("data", 0, false)) == -1)
-    throw error_c("wav_reader: No data chunk was found.");
+    throw error_c(Y("wav_reader: No data chunk was found."));
 
   m_io->setFilePointer(m_chunks[m_cur_data_chunk_idx].pos + sizeof(struct chunk_struct), seek_beginning);
 
@@ -521,7 +523,7 @@ wav_reader_c::create_demuxer() {
     m_demuxer = wav_demuxer_cptr(new wav_pcm_demuxer_c(this, &m_wheader, ieee_float));
 
   if (verbose)
-    mxinfo(FMT_FN "Using the WAV demultiplexer.\n", ti.fname.c_str());
+    mxinfo_fn(ti.fname, Y("Using the WAV demultiplexer.\n"));
 }
 
 void
@@ -535,7 +537,7 @@ wav_reader_c::create_packetizer(int64_t) {
 file_status_e
 wav_reader_c::read(generic_packetizer_c *,
                    bool) {
-  int64_t        requested_bytes = MXMIN(m_remaining_bytes_in_current_data_chunk, m_demuxer->get_preferred_input_size());
+  int64_t        requested_bytes = std::min(m_remaining_bytes_in_current_data_chunk, m_demuxer->get_preferred_input_size());
   unsigned char *buffer          = m_demuxer->get_buffer();
   int64_t        num_read;
 
@@ -582,8 +584,9 @@ wav_reader_c::scan_chunks() {
 
       new_chunk.len = m_io->read_uint32_le();
 
-      mxverb(2, "wav_reader_c::scan_chunks() new chunk at " LLD " type %s length " LLD "\n",
-             new_chunk.pos, get_displayable_string(new_chunk.id, 4).c_str(), new_chunk.len);
+      mxverb(2,
+             boost::format(Y("wav_reader_c::scan_chunks() new chunk at %1% type %2% length %3%\n"))
+             % new_chunk.pos % get_displayable_string(new_chunk.id, 4) % new_chunk.len);
 
       if (!strncasecmp(new_chunk.id, "data", 4))
         m_bytes_in_data_chunks += new_chunk.len;
@@ -595,8 +598,9 @@ wav_reader_c::scan_chunks() {
         m_bytes_in_data_chunks      += this_chunk_len;
         previous_chunk.len           = this_chunk_len;
 
-        mxverb(2, "wav_reader_c::scan_chunks() hugh data chunk with wrong length at " LLD "; re-calculated from file size; new length " LLD "\n",
-               previous_chunk.pos, previous_chunk.len);
+        mxverb(2,
+               boost::format(Y("wav_reader_c::scan_chunks() hugh data chunk with wrong length at %1%; re-calculated from file size; new length %2%\n"))
+               % previous_chunk.pos % previous_chunk.len);
 
         break;
       }
