@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mkvmerge.h 3827 2008-08-18 20:41:40Z mosu $
+   $Id: mkvmerge.h 3923 2008-09-21 14:31:14Z mosu $
 
    definition of global variables found in mkvmerge.cpp
 
@@ -35,6 +35,7 @@ enum file_type_e {
   FILE_TYPE_AVI,
   FILE_TYPE_CHAPTERS,
   FILE_TYPE_COREPICTURE,
+  FILE_TYPE_DIRAC,
   FILE_TYPE_DTS,
   FILE_TYPE_FLAC,
   FILE_TYPE_FLV,
@@ -51,6 +52,7 @@ enum file_type_e {
   FILE_TYPE_SSA,
   FILE_TYPE_TTA,
   FILE_TYPE_USF,
+  FILE_TYPE_VC1,
   FILE_TYPE_VOBBTN,
   FILE_TYPE_VOBSUB,
   FILE_TYPE_WAV,
