@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: timecode_factory.h 3018 2005-08-12 10:56:07Z mosu $
+   $Id: timecode_factory.h 3978 2008-10-09 07:50:55Z mosu $
 
    class definition for the timecode factory
 
@@ -21,6 +21,7 @@
 #include <string>
 #include <vector>
 
+#include "smart_pointers.h"
 #include "packet.h"
 
 using namespace std;
@@ -51,6 +52,9 @@ public:
   bool is_gap;
 };
 
+class timecode_factory_c;
+typedef counted_ptr<timecode_factory_c> timecode_factory_cptr;
+
 class timecode_factory_c {
 protected:
   string m_file_name, m_source_name;
@@ -58,12 +62,14 @@ protected:
   int m_version;
 
 public:
-  timecode_factory_c(const string &file_name, const string &source_name,
-                     int64_t tid, int version):
-    m_file_name(file_name),
-    m_source_name(source_name),
-    m_tid(tid),
-    m_version(version) {
+  timecode_factory_c(const string &file_name,
+                     const string &source_name,
+                     int64_t tid, int version)
+    : m_file_name(file_name)
+    , m_source_name(source_name)
+    , m_tid(tid)
+    , m_version(version)
+  {
   }
   virtual ~timecode_factory_c() {
   }
@@ -83,9 +89,7 @@ public:
     return false;
   }
 
-  static timecode_factory_c *create(const string &file_name,
-                                    const string &source_name,
-                                    int64_t tid);
+  static timecode_factory_cptr create(const string &file_name, const string &source_name, int64_t tid);
 };
 
 class timecode_factory_v1_c: public timecode_factory_c {
@@ -96,12 +100,14 @@ protected:
   double m_default_fps;
 
 public:
-  timecode_factory_v1_c(const string &file_name, const string &source_name,
-                        int64_t tid):
-    timecode_factory_c(file_name, source_name, tid, 1),
-    m_current_range(0),
-    m_frameno(0),
-    m_default_fps(0.0) {
+  timecode_factory_v1_c(const string &file_name,
+                        const string &source_name,
+                        int64_t tid)
+    : timecode_factory_c(file_name, source_name, tid, 1)
+    , m_current_range(0)
+    , m_frameno(0)
+    , m_default_fps(0.0)
+  {
   }
   virtual ~timecode_factory_v1_c() {
   }
@@ -109,8 +115,7 @@ public:
   virtual void parse(mm_io_c &in);
   virtual bool get_next(packet_cptr &packet);
   virtual double get_default_duration(double proposal) {
-    return m_default_fps != 0.0 ? (double)1000000000.0 / m_default_fps :
-      proposal;
+    return 0.0 != m_default_fps ? (double)1000000000.0 / m_default_fps : proposal;
   }
 
 protected:
@@ -125,12 +130,14 @@ protected:
   bool m_warning_printed;
 
 public:
-  timecode_factory_v2_c(const string &file_name, const string &source_name,
-                        int64_t tid, int version):
-    timecode_factory_c(file_name, source_name, tid, version),
-    m_frameno(0),
-    m_default_fps(0.0),
-    m_warning_printed(false) {
+  timecode_factory_v2_c(const string &file_name,
+                        const string &source_name,
+                        int64_t tid, int version)
+    : timecode_factory_c(file_name, source_name, tid, version)
+    , m_frameno(0)
+    , m_default_fps(0.0)
+    , m_warning_printed(false)
+  {
   }
   virtual ~timecode_factory_v2_c() {
   }
@@ -138,8 +145,7 @@ public:
   virtual void parse(mm_io_c &in);
   virtual bool get_next(packet_cptr &packet);
   virtual double get_default_duration(double proposal) {
-    return m_default_fps != 0.0 ? (double)1000000000.0 / m_default_fps :
-      proposal;
+    return m_default_fps != 0.0 ? (double)1000000000.0 / m_default_fps : proposal;
   }
 };
 
@@ -152,13 +158,15 @@ protected:
   double m_default_fps;
 
 public:
-  timecode_factory_v3_c(const string &file_name, const string &source_name,
-                        int64_t tid):
-    timecode_factory_c(file_name, source_name, tid, 3),
-    m_current_duration(0),
-    m_current_timecode(0),
-    m_current_offset(0),
-    m_default_fps(0.0) {
+  timecode_factory_v3_c(const string &file_name,
+                        const string &source_name,
+                        int64_t tid)
+    : timecode_factory_c(file_name, source_name, tid, 3)
+    , m_current_duration(0)
+    , m_current_timecode(0)
+    , m_current_offset(0)
+    , m_default_fps(0.0)
+  {
   }
   virtual void parse(mm_io_c &in);
   virtual bool get_next(packet_cptr &packet);
