@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: jobs.cpp 3559 2007-07-05 14:56:32Z mosu $
+   $Id: jobs.cpp 3976 2008-10-07 21:49:31Z mosu $
 
    job queue management dialog
 
@@ -233,7 +233,7 @@ job_run_dialog::process_input() {
 #else
       wx_line = from_utf8(cc_local_utf8, line).c_str();
 #endif
-      if (wx_line.Find(wxT("progress")) == 0) {
+      if (wx_line.Find(wxT("Progress")) == 0) {
         if (wx_line.Find(wxT("%")) != 0) {
           wx_line.Remove(wx_line.Find(wxT("%")));
           tmp = wx_line.AfterLast(wxT(' '));
