@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: kax_analyzer.cpp 2711 2005-01-12 15:03:47Z mosu $
+   $Id: kax_analyzer.cpp 3967 2008-10-05 14:54:00Z mosu $
 
    Matroska file analyzer
 
@@ -33,13 +33,13 @@
 using namespace std;
 using namespace libebml;
 
-// static void dumpme(vector<analyzer_data_c *> &data) {
-//   uint32_t i;
+// static void
+// dump_analyzer_data(vector<analyzer_data_c *> &data) {
+//   int i;
 
 //   mxinfo("DATA dump:\n");
 //   for (i = 0; i < data.size(); i++)
-//     mxinfo("%03d: 0x%08x at %lld, size %lld\n", i, data[i]->id.Value,
-//            data[i]->pos, data[i]->size);
+//     mxinfo(boost::format("%|1$04d|: 0x%|2$08x| at %3% size %4%\n") % i % data[i]->id.Value % data[i]->pos % data[i]->size);
 // }
 
 kax_analyzer_dlg_c::kax_analyzer_dlg_c(wxWindow *_parent,
@@ -117,11 +117,9 @@ kax_analyzer_dlg_c::process() {
   upper_lvl_el = 0;
   // We've got our segment, so let's find all level 1 elements.
   l1 = es.FindNextElement(segment->Generic().Context, upper_lvl_el,
-                          0xFFFFFFFFL, true, 1);
+                          0xFFFFFFFFFFFFFFFFLL, true, 1);
   while ((l1 != NULL) && (upper_lvl_el <= 0)) {
-    data.push_back(new analyzer_data_c(l1->Generic().GlobalId,
-                                       l1->GetElementPosition(),
-                                       l1->ElementSize()));
+    data.push_back(new analyzer_data_c(l1->Generic().GlobalId, l1->GetElementPosition(), l1->ElementSize(true)));
     while (app->Pending())
       app->Dispatch();
 
@@ -166,7 +164,7 @@ kax_analyzer_c::kax_analyzer_c(wxWindow *_parent,
   file_name(_name),
   segment(NULL) {
   try {
-    file = new mm_file_io_c(file_name.c_str(), MODE_SAFE);
+    file = new mm_file_io_c(file_name.c_str(), MODE_WRITE);
   } catch (...) {
     throw error_c(string("Could not open the file " + file_name + "."));
   }
@@ -323,11 +321,9 @@ kax_analyzer_c::overwrite_elements(EbmlElement *e,
         file->setFilePointer(data[i]->pos);
         evoid.Render(*file);
         data[i]->size = size;
-        while (data[i + 1]->id == EbmlVoid::ClassInfos.GlobalId) {
-          dit = data.begin();
-          dit += i + 1;
-          data.erase(dit);
-        }
+        while (((i + 1) < data.size()) &&
+               (data[i + 1]->id == EbmlVoid::ClassInfos.GlobalId))
+          data.erase(data.begin() + i + 1);
       }
     }
     i++;
@@ -342,7 +338,6 @@ kax_analyzer_c::update_element(EbmlElement *e) {
   int64_t space_here, pos;
   vector<KaxSeekHead *> all_heads;
   vector<int64_t> free_space;
-  vector<analyzer_data_c *>::iterator dit;
   KaxSegment *new_segment;
   KaxSeekHead *new_head;
   EbmlElement *new_e;
@@ -356,6 +351,9 @@ kax_analyzer_c::update_element(EbmlElement *e) {
     data[i]->delete_this = false;
 
   try {
+//     mxinfo(boost::format("INFO 0:\n"));
+//     dump_analyzer_data(data);
+
     found_what = 0;
     for (i = 0; i < data.size(); i++)
       if (data[i]->id == EbmlId(*e)) {
@@ -433,17 +431,17 @@ kax_analyzer_c::update_element(EbmlElement *e) {
       overwrite_elements(e, found_where);
 
     // Remove the internal elements. Avoids re-analyzing the file.
-    dit = data.begin();
-    while (dit < data.end()) {
-      if ((*dit)->delete_this) {
-        delete *dit;
-        data.erase(dit);
+    i = 0;
+    while (data.size() > i) {
+      if (data[i]->delete_this) {
+        delete data[i];
+        data.erase(data.begin() + i);
       } else
-        dit++;
+        ++i;
     }
 
-//     mxinfo("INFO:\n%s", info.c_str());
-//     dumpme(data);
+//     mxinfo(boost::format("INFO 1:\n%1%\n") % info);
+//     dump_analyzer_data(data);
 
     // 1. Find all seek heads.
     free_space.clear();
@@ -571,8 +569,9 @@ kax_analyzer_c::update_element(EbmlElement *e) {
       all_heads.push_back(all_heads[0]);
       all_heads.erase(all_heads.begin());
       all_heads.insert(all_heads.begin(), new_head);
-//       mxinfo("MORE INFO:\n%s", info.c_str());
-//       dumpme(data);
+
+//       mxinfo(boost::format("INFO 2:\n%1%\n") % info);
+//       dump_analyzer_data(data);
 
       throw true;
     }
@@ -598,7 +597,7 @@ kax_analyzer_c::update_element(EbmlElement *e) {
     if (found_what) {
       all_heads.insert(all_heads.begin(), new_head);
       overwrite_elements(new_head, found_where);
-//       dumpme(data);
+//       dump_analyzer_data(data);
 
       throw true;
     } else
@@ -620,10 +619,10 @@ kax_analyzer_c::update_element(EbmlElement *e) {
     all_heads.clear();
 
 //     mxinfo("DUMP after work:\n");
-//     dumpme(data);
+//     dump_analyzer_data(data);
 //     process();
 //     mxinfo("DUMP after re-process()ing:\n");
-//     dumpme(data);
+//     dump_analyzer_data(data);
 
     return b;
   }
