@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mux_dialog.cpp 3559 2007-07-05 14:56:32Z mosu $
+   $Id: mux_dialog.cpp 3946 2008-09-28 21:05:53Z mosu $
 
    muxing dialog
 
@@ -169,7 +169,7 @@ mux_dialog::mux_dialog(wxWindow *parent):
         tc_warnings->AppendText(wx_line + wxT("\n"));
       else if (wx_line.Find(wxT("Error:")) == 0)
         tc_errors->AppendText(wx_line + wxT("\n"));
-      else if (wx_line.Find(wxT("progress")) == 0) {
+      else if (wx_line.Find(wxT("Progress")) == 0) {
         if (wx_line.Find(wxT("%")) != 0) {
           wx_line.Remove(wx_line.Find(wxT("%")));
           tmp = wx_line.AfterLast(wxT(' '));
